pub enum EncodedWordEncoding {
    Base64,
    QuotedPrintable,
}

Variants

Base64

QuotedPrintable

Implementations

returns the acronym for the given encoding used in a encoded word

encodes a given utf8 string

either self::quoted_printable::encoded_word_encode or self::base64::encoded_word_encode_utf8 is used depending on which value self is.

As both algorithm need to know about code point boundaries only encoding utf8 is supported for now