pub enum EncodedWordEncoding {
Base64,
QuotedPrintable,
}Variants
Implementations
sourceimpl EncodedWordEncoding
impl EncodedWordEncoding
sourcepub fn acronym(&self) -> &'static SoftAsciiStr
pub fn acronym(&self) -> &'static SoftAsciiStr
returns the acronym for the given encoding used in a encoded word
sourcepub fn encode<R, O>(&self, input: R, out: &mut O)where
R: AsRef<str>,
O: EncodedWordWriter,
pub fn encode<R, O>(&self, input: R, out: &mut O)where
R: AsRef<str>,
O: EncodedWordWriter,
encodes a given utf8 string
either self::quoted_printable::encoded_word_encode
or self::base64::encoded_word_encode_utf8 is used
depending on which value self is.
As both algorithm need to know about code point boundaries only encoding utf8 is supported for now