Struct mail_internals::bind::quoted_string::MailQsSpec
source · pub struct MailQsSpec;Expand description
A Quoted String specification in context of Mail (rfc5322)
This implementation of MailQsSpec does not include support for the obsolete parts of the grammar as it’s meant for generation/encoding and no obsolete parts should be generated at all (Through a parser would have to be able to parse them for compatibility reasons).